.. _under_sampling_api:

Under-sampling-based ensembles
================================

.. automodule:: imbalanced_ensemble.ensemble.under_sampling
    :no-members:
    :no-inherited-members:

.. currentmodule:: imbalanced_ensemble.ensemble.under_sampling

.. autosummary::
   :toctree: _autosummary
   :template: class.rst

   SelfPacedEnsembleClassifier
   BalanceCascadeClassifier
   BalancedRandomForestClassifier
   EasyEnsembleClassifier
   RUSBoostClassifier
   UnderBaggingClassifier